import net.sf.emff.EMFF;
import net.sf.emff.configuration.Configuration;

import net.sf.flashlib.lang.NullPointerException;
import net.sf.flashlib.util.Delegate;



/**
 * Utility to add the possibility of groupable EMFFs.
 * This utility is used in order that only one EMFF instance should be possible to play at a time.
 * 
 * @version 0.0.2
 */
class net.sf.emff.GroupUtil {
	
	private var receiver : LocalConnection = null;
	private var sender : LocalConnection = null;
	private var groupname : String = null;
	private var id : Number = 0;
	private var emff : EMFF = null;
	private var activeId : Number = -1;
	
	
	/**
	 * Creates the group utility.
	 * 
	 * @param emff 
	 */
	public function GroupUtil(emff : EMFF) {
		
		if (emff == null) {
			throw new NullPointerException();
		}
		
		var configuration : Configuration = emff.getConfiguration();
		
		if (configuration.groupname != null && configuration.groupname != "") {
			this.groupname = configuration.groupname;
			this.emff = emff;
			
			receiver = new LocalConnection();
			sender = new LocalConnection();
			while (!receiver.connect("emff_" + groupname + "_" + id)) {
				id++;
			}
			
			receiver.setActiveID = Delegate.create(this, setActiveID);
		}
		
	}
	
	/**
	 * Sets the id of the single active EMFF instance.
	 * 
	 * @param activeId ID of the EMFF instance that is the new active one.
	 */
	private function setActiveID(activeId : Number) : Void {
		if (activeId != id) {
			emff.stop();
		}
		
		if (id == 0) {
			// master instance
			if (this.activeId != -1 && this.activeId != 0) {
				sender.send("emff_" + groupname + "_" + this.activeId, "setActiveID", activeId);
			}
			
			// save active EMFF
			this.activeId = activeId;
		}
	}
	
	/**
	 * Activates own EMFF instance (stops all other instances).
	 */
	public function setActive() : Void {
		if (groupname != null) {
			sender.send("emff_" + groupname + "_0", "setActiveID", id);
		}
	}
	
}
