/**
 * Update utility that checks for the required flash version and displays
 * an update notice in the case that the flash plugin is too old.
 * 
 * @author  Marc Reichelt
 * @version 0.0.1
 */
class net.sf.emff.UpdateUtil {
	
	/**
	 * The required Flash version for all skins.
	 */
	public static /* const */ var REQUIRED_FLASH_VERSION : Number = 7;
	
	/**
	 * The URL where the user can install a new flash player.
	 */
	public static /* const */ var FLASH_UPDATE_URL : String = "http://www.adobe.com/shockwave/download/download.cgi?P1_Prod_Version=ShockwaveFlash";
	
	
	
	private static var instance : UpdateUtil = null;
	
	/**
	 * Returns the single instance of this class.
	 */
	public static function getInstance() : UpdateUtil {
		if (instance == null) {
			instance = new UpdateUtil();
		}
		
		return instance;
	}
	
	/**
	 * Current version of this Flash player.
	 */
	private var version : Number;
	
	/**
	 * Looks up the current version and checks if an update is required.
	 * If an update is required a notice is displayed.
	 */
	private function UpdateUtil() {
		// get flash version
		var start : Number = getVersion().indexOf(" ");
		var end : Number = getVersion().indexOf(",");
		version = Number(getVersion().slice(start + 1, end));
		
		// check for flash version and display a notice.
		if (updateNeeded()) {
			showUpdateNotice();
		}
	}
	
	/**
	 * Gets the current Flash version.
	 * 
	 * @return Current version of this Flash Player (only the major release).
	 */
	public function getFlashVersion() : Number {
		return version;
	}
	
	/**
	 * Checks if an update is needed.
	 * 
	 * @return <code>true</code> if an update if required (the Flash player is too
	 *          old), <code>false</code> otherwise.
	 */
	public function updateNeeded() : Boolean {
		return (version < UpdateUtil.REQUIRED_FLASH_VERSION);
	}
	
	/**
	 * Shows the update notice.
	 * The update notice is an image indicating that the user should click on it to get
	 * a new Flash version. It is centered in the middle of the Stage if enough space is
	 * left, otherwise it is scaled.
	 */
	private function showUpdateNotice() : Void {
		var mc : MovieClip = _root.attachMovie("updatenotice", "updatenoticeMC", _root.getNextHighestDepth());
		
		var xscale : Number = Stage.width / mc._width;
		var yscale : Number = Stage.height / mc._height;
		if (xscale < 1.0 || yscale < 1.0) {
			mc._xscale = yscale * 100;
			mc._yscale = yscale * 100;
		}
		
		if (xscale < 1.0) {
			mc._x = 0;
			mc._y = 0;
		} else {
			mc._x = Math.round((Stage.width - mc._width) / 2);
			mc._y = Math.round((Stage.height - mc._height) / 2);
		}
		
		mc.onRelease = function() {
			getURL(UpdateUtil.FLASH_UPDATE_URL);
		};
	}
	
}
