import net.sf.flashlib.lang.Exception;



/**
 * Thrown if parsing of XML data failed.
 * 
 * @version 0.2.0
 * @author  Marc Reichelt
 */
class net.sf.flashlib.xml.XMLParseException extends Exception {
	
	/**
	 * Status code of a XML parser.
	 */
	private var status : Number;
	
	
	
	/**
	 * Creates a new XMLParseException.
	 * 
	 * @param  status  The status code of the XML parser.
	 */
	public function XMLParseException(status : Number) {
		super("");
		this.status = status;
	}
	
	
	
	/**
	 * Returns the name of this exception.
	 * 
	 * @return  Name of this exception.
	 * @see     net.sf.flashlib.lang.Exception#getName()
	 */
	public function getName() : String {
		return "XMLParseException";
	}
	
	/**
	 * Returns the message of this exception.
	 * 
	 * @return  Message of this exception.
	 * @see     net.sf.flashlib.lang.Exception#getMessage()
	 */
	public function getMessage() : String {
		
		if (status == null) {
			return super.getMessage();
		} else {
			switch (status) {
			case 0:
				return "No error, parse completed successfully.";
			case -2:
				return "A CDATA section was not properly terminated.";
			case -3:
				return "The XML declaration was not properly terminated.";
			case -4:
				return "The DOCTYPE declaration was not properly terminated.";
			case -5:
				return "A comment was not properly terminated.";
			case -6:
				return "An XML element was malformed.";
			case -7:
				return "Out of memory.";
			case -8:
				return "An attribute value was not properly terminated.";
			case -9:
				return "A start-tag was not matched with an end-tag.";
			case -10:
				return "An end-tag was encountered without a matching start-tag.";
			default:
				return "Unknown error.";
			}
		}
	}
	
}
